/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useState, useEffect, useContext } from "react";
import PropTypes from "prop-types";
import SwipeableViews from "react-swipeable-views";
import moment from "moment";
//imports material ui components
import { Typography, TextField, Button, Grid } from "@material-ui/core";
import CircularProgress from "@material-ui/core/CircularProgress";
import Card from "@material-ui/core/Card";
import CardContent from "@material-ui/core/CardContent";
import CardAction from "@material-ui/core/CardActions";
import ListRoundedIcon from "@material-ui/icons/ListRounded";
import Chip from "@material-ui/core/Chip";
import MenuItem from "@material-ui/core/MenuItem";
import { useTheme, makeStyles } from "@material-ui/core/styles";
import Tabs from "@material-ui/core/Tabs";
import Tab from "@material-ui/core/Tab";
import Box from "@material-ui/core/Box";
import SaveIcon from "@material-ui/icons/Save";
//imports local files
import SnackBar from "../../../../Components/SnackbarComponent";
import { Store } from "../../../../Store";
import Unauthorized from "../Unauthorized";
import LoadingSpinner from "../../../../Components/LoadingSpinner";
import {
    fetchAllRequest,
    putRequest,
} from "../../../../Components/HelperFunctions/getAxiosConfig";
import { EditFilter } from "../../../Filters";
//routers
import { Link } from "react-router-dom";
import ClassicEditor from "@ckeditor/ckeditor5-build-classic"
import { CKEditor } from '@ckeditor/ckeditor5-react';

const useStyles = makeStyles((theme) => ({
    root: {
        width: "100%",
        maxWidth: 250,
        backgroundColor: theme.palette.background.paper,
        position: "relative",
        overflow: "auto",
        maxHeight: 300,
    },
}));

let text;

const EditEducationalObject = ({ match }) => {
    const { state } = useContext(Store);

    const theme = useTheme();
    const classes = useStyles();

    const id = match.params.id;

    const [error, setError] = useState(null); //Necessary to consult the API, catch errors
    const [isLoaded, setIsLoaded] = useState(false); //Necessary to consult the API, wait until complete
    const [isLoading, setIsLoading] = useState(false); //is loading to submit

    const [value, setValue] = React.useState(0);

    //mutables
    const [name, setName] = useState();
    const [owner, setOwner] = useState();
    const [author, setAuthor] = useState();
    const [objectType, setObjectType] = useState({});
    const [description, setDescription] = useState("");
    const [languagesID, setLanguagesID] = useState([]);
    const [listOfLanguages, setListOfLanguages] = useState([]);
    const [listOfObjectTypes, setListOfObjectTypes] = useState([]);

    // Imutables
    const [CREATE_AT, setCreateAt] = useState("");
    const [UPDATE_AT, setUpdateAt] = useState("");
    const [VIEWS_COUNT, setViewsCount] = useState("");
    const [LIKES_COUNT, setLikesCount] = useState("");
    const [REVIEW_AVERAGE, setReviewAverage] = useState("");
    const [SCORE, setScore] = useState("");

    const [errorInName, setErrorInName] = useState({
        error: false,
        message: "",
    });

    const [errorInOwner, setErrorInOwner] = useState({
        error: false,
        message: "",
    });

    const [errorInAuthor, setErrorInAuthor] = useState({
        error: false,
        message: "",
    });

    const [snackInfo, setSnackInfo] = useState({
        message: "",
        icon: "",
        open: false,
        color: "",
    });

    const NameHandler = (e) => {
        if (errorInName.error) {
            setErrorInName({
                error: false,
                message: "",
            });
        }
        setName(e.target.value);
    };

    const OwnerHandler = (e) => {
        if (errorInOwner.error) {
            setErrorInOwner({
                error: false,
                message: "",
            });
        }
        setOwner(e.target.value);
    };

    const AuthorHandler = (e) => {
        if (errorInAuthor.error) {
            setErrorInAuthor({
                error: false,
                message: "",
            });
        }
        setAuthor(e.target.value);
    };

    function TabPanel(props) {
        const { children, value, index, ...other } = props;

        return (
            <div
                role="tabpanel"
                hidden={value !== index}
                id={`full-width-tabpanel-${index}`}
                aria-labelledby={`full-width-tab-${index}`}
                {...other}
            >
                {value === index && <Box style={{ marginTop: "2em" }}>{children}</Box>}
            </div>
        );
    }

    TabPanel.propTypes = {
        children: PropTypes.node,
        index: PropTypes.any.isRequired,
        value: PropTypes.any.isRequired,
    };

    function a11yProps(index) {
        return {
            id: `full-width-tab-${index}`,
            "aria-controls": `full-width-tabpanel-${index}`,
        };
    }

    const handleChangeLan = (id, value) => {
        const currLanguagesId = [...languagesID];
        currLanguagesId.push({
            id: id,
            name: value,
        });
        setListOfLanguages((chips) => chips.filter((chip) => chip.id !== id));
        setLanguagesID(currLanguagesId);
    };

    const handleDeleteLan = (chipToDelete) => () => {
        const currLanguageList = [...listOfLanguages];
        currLanguageList.push({
            id: chipToDelete.id,
            name: chipToDelete.name,
        });
        setListOfLanguages(currLanguageList);
        setLanguagesID((chips) =>
            chips.filter((chip) => chip.id !== chipToDelete.id)
        );
    };

    const handleChangeObj = (id, value) => {
        let currListOfObjs = [...listOfObjectTypes];
        currListOfObjs.push({
            id: objectType.id,
            name: objectType.name,
        });
        currListOfObjs = currListOfObjs.filter((chip) => chip.id !== id);
        setListOfObjectTypes(currListOfObjs);
        setObjectType({
            id: id,
            name: value,
        });
    };

    const handleChangeTab = (event, newValue) => {
        setValue(newValue);
    };

    const handleChangeIndex = (index) => {
        setValue(index);
    };

    // Handle snack infos
    const HandleSnack = (message, state, icon, color) => {
        setSnackInfo({
            message: message,
            icon: icon,
            open: state,
            color: color,
        });
    };

    const SaveData = (data) => {
        setName(data.name);
        setOwner(data.publisher.name);
        setAuthor(data.author);
        setReviewAverage(data.review_average);
        setLikesCount(data.likes_count);
        setViewsCount(data.views_count);
        setScore(data.score);
        setCreateAt(DisplayDate(data.created_at));
        setUpdateAt(DisplayDate(data.updated_at));
        setDescription(data.description);
    };

    const DisplayDate = (date) => {
        const convertedData = moment.utc(date);
        return moment(convertedData)
            .format("LLL")
            .toString();
    };

    //handle submit
    const onSubmit = async () => {
        setIsLoading(true);
        const api = EditFilter("learning_objects", id);
        const body = {
            "learning_object": {
                "author": author,
                "name": name,
                "description": text,
                "object_type_id": [objectType.id],
                "language_ids": languagesID,
            },
        };
        console.log(text)
        putRequest(
            api,
            body,
            (data, header) => {
                if (data.id) {
                    HandleSnack(
                        "O objeto educacional foi alterada com sucesso",
                        true,
                        "success",
                        "#228B22"
                    );
                } else {
                    if(data.errors){
                        HandleSnack(`${data.errors[0]}`, true, 'warning', '#FA8072')
                    }
                    if (data.author) {
                        let authorError = "";
                        data.author.map((msg) => (authorError = authorError + msg + " e "));
                        setErrorInAuthor({
                            error: true,
                            message: authorError,
                        });
                    }
                    if (data.language) {
                        let languageErr = "";
                        data.language.map(
                            (msg) => (languageErr = languageErr + msg + " e ")
                        );
                        HandleSnack("Língua" + languageErr, true, "warning", "#FFC125");
                    }
                }
                setIsLoading(false);
            },
            (error) => {
                HandleSnack("Ocorreu algum erro", true, "warning", "#FA8072");
                setIsLoading(false);
            }
        );
    };

    // Fields
    const fields = [
        {
            label: "ID",
            value: id,
            default: true,
            type: "text",
        },
        {
            label: "Nome",
            value: name,
            error: errorInName.error,
            errorMessage: errorInName.message,
            onChange: (event) => NameHandler(event),
            default: false,
            required: true,
            type: "text",
        },
        {
            label: "Dono(a)",
            value: owner,
            error: errorInOwner.error,
            errorMessage: errorInOwner.message,
            onChange: (event) => OwnerHandler(event),
            default: false,
            required: true,
            type: "text",
        },
        {
            label: "Autor(a)",
            value: author,
            error: errorInAuthor.error,
            errorMessage: errorInAuthor.message,
            onChange: (event) => AuthorHandler(event),
            default: false,
            required: true,
            type: "text",
        },
    ];

    const Imutables = [
        {
            label: "Score",
            value: SCORE,
            default: true,
            type: "text",
        },
        {
            label: "Criado em",
            value: CREATE_AT,
            default: true,
            type: "text",
        },
        {
            label: "Atualizado em",
            value: UPDATE_AT,
            default: true,
            type: "text",
        },
        {
            label: "View count",
            value: VIEWS_COUNT,
            default: true,
            type: "text",
        },
        {
            label: "Likes count",
            value: LIKES_COUNT,
            default: true,
            type: "text",
        },
        {
            label: "Review average",
            value: REVIEW_AVERAGE,
            default: true,
            type: "text",
        },
    ];

    const CheckUserPermission = () => {
        let canUserEdit = false;

        if (state.userIsLoggedIn) {
            const roles = [...state.currentUser.roles];
            for (let i = 0; i < roles.length; i++)
                if (roles[i].name === "admin" || roles[i].name === "editor")
                    canUserEdit = true;
        } else {
            canUserEdit = false;
        }

        return canUserEdit;
    };

    useEffect(() => {
        const urls = [
            `/learning_objects/${match.params.id}`,
            "/languages",
            "/object_types",
        ];
        fetchAllRequest(
            urls,
            (data) => {
                const auxiliarLanguages = [...data[1]];
                const auxiliarLanguagesId = [];
                const objectLanguagesId = [];
                data[0].language.map((lan) => objectLanguagesId.push(lan.id));
                data[1].map((lan) => auxiliarLanguagesId.push(lan.id));
                for (let i = 0; i < objectLanguagesId.length; i++) {
                    const lan = objectLanguagesId[i];
                    const index = auxiliarLanguagesId.indexOf(lan);
                    auxiliarLanguages.splice(index, 1);
                    auxiliarLanguagesId.splice(index, 1);
                }
                const auxiliarObjects = [...data[2]];
                const auxiliarObjectsName = [];
                const objectTypeName = data[0].object_type;
                data[2].map((obj) => auxiliarObjectsName.push(obj.name));
                const index = auxiliarObjectsName.indexOf(objectTypeName);
                setObjectType({
                    id: auxiliarObjects[index].id,
                    name: auxiliarObjects[index].name,
                });
                auxiliarObjects.splice(index, 1);
                auxiliarObjectsName.splice(index, 1);

                SaveData(data[0]);
                setLanguagesID(data[0].language);
                setListOfLanguages(auxiliarLanguages);
                setListOfObjectTypes(auxiliarObjects);
                setIsLoaded(true);
            },
            (error) => {
                console.log(error);
                setError(true);
            }
        );
    }, []);

    if (error) {
        return <div> Houve um erro... </div>;
    } else if (!isLoaded) {
        return <LoadingSpinner text="Carregando..." />;
    } else if (CheckUserPermission()) {
        return (
            <Card variant="outlined">
                <SnackBar
                    severity={snackInfo.icon}
                    text={snackInfo.message}
                    snackbarOpen={snackInfo.open}
                    color={snackInfo.color}
                    handleClose={() =>
                        setSnackInfo({
                            message: "",
                            icon: "",
                            open: false,
                            color: "",
                        })
                    }
                />
                <CardContent>
                    <Grid
                        container
                        direction="row"
                        justify="space-between"
                        xs={12}
                        alignContent="center"
                        alignItems="center"
                    >
                        <Grid item>
                            <Typography variant="h4">{name}</Typography>
                        </Grid>
                        <Grid item>
                            <Link
                                style={{ textDecoration: "none" }}
                                to={"/admin/learningObjects"}
                            >
                                <Button
                                    startIcon={<ListRoundedIcon />}
                                    variant="outlined"
                                    color="primary"
                                >
                                    Listar
                                </Button>
                            </Link>
                        </Grid>
                    </Grid>

                    <Tabs
                        value={value}
                        onChange={handleChangeTab}
                        indicatorColor="primary"
                        textColor="primary"
                        variant="fullWidth"
                        aria-label="full width tabs example"
                    >
                        <Tab label="Resumo" {...a11yProps(0)} />
                        <Tab label="Descrição" {...a11yProps(1)} />
                        <Tab label="Imutáveis" {...a11yProps(2)} />
                    </Tabs>

                    <SwipeableViews
                        axis={theme.direction === "rtl" ? "x-reverse" : "x"}
                        index={value}
                        onChangeIndex={handleChangeIndex}
                    >
                        <TabPanel value={value} index={0} dir={theme.direction}>
                            <form style={{ display: "flex", flexDirection: "column" }}>
                                {fields.map((field, index) => (
                                    <TextField
                                        key={index}
                                        required={field.required}
                                        disabled={field.default}
                                        error={field.error}
                                        helperText={field.error ? field.errorMessage : ""}
                                        style={{ width: "250px", marginBottom: "1em" }}
                                        label={field.label}
                                        defaultValue={field.value}
                                        onBlur={field.onChange}
                                        type="search"
                                        multiline
                                    />
                                ))}
                                {languagesID.map((data) => {
                                    return (
                                        <li
                                            key={data.id}
                                            style={{ listStyleType: "none", marginBottom: "0.5em" }}
                                        >
                                            <Chip
                                                label={data.name}
                                                onDelete={
                                                    data === "React" ? undefined : handleDeleteLan(data)
                                                }
                                                className={classes.chip}
                                            />
                                        </li>
                                    );
                                })}
                                <TextField
                                    id="standard-select-currency"
                                    select
                                    label="Línguas"
                                    style={{ width: "250px", marginBottom: "1em" }}
                                >
                                    {listOfLanguages.map((option) => (
                                        <MenuItem
                                            key={option.id}
                                            value={option.name}
                                            onClick={() => {
                                                handleChangeLan(option.id, option.name);
                                            }}
                                        >
                                            {option.name}
                                        </MenuItem>
                                    ))}
                                </TextField>

                                <li style={{ listStyleType: "none", marginBottom: "0.5em" }}>
                                    <Chip label={objectType.name} className={classes.chip} />
                                </li>
                                <TextField
                                    id="standard-select-currency"
                                    select
                                    label="Object type"
                                    style={{ width: "250px", marginBottom: "1em" }}
                                >
                                    {listOfObjectTypes.map((option) => (
                                        <MenuItem
                                            key={option.id}
                                            value={option.name}
                                            onClick={() => {
                                                handleChangeObj(option.id, option.name);
                                            }}
                                        >
                                            {option.name}
                                        </MenuItem>
                                    ))}
                                </TextField>
                            </form>
                        </TabPanel>

                        <TabPanel value={value} index={1} dir={theme.direction}>
                            <CKEditor
                                editor={ClassicEditor}
                                data={description}
                                onBlur={(event, editor) => {
                                    const data = editor.getData();
                                    setDescription(data)
                                }}
                            />
                        </TabPanel>

                        <TabPanel value={value} index={2} dir={theme.direction}>
                            <form style={{ display: "flex", flexDirection: "column" }}>
                                {Imutables.map((field, index) => (
                                    <TextField
                                        key={index}
                                        disabled={field.default}
                                        style={{ width: "250px", marginBottom: "1em" }}
                                        label={field.label}
                                        defaultValue={field.value}
                                    />
                                ))}
                            </form>
                        </TabPanel>
                    </SwipeableViews>
                </CardContent>

                <CardAction>
                    <Button
                        onClick={() => {
                            onSubmit();
                        }}
                        variant="contained"
                        color="primary"
                        disabled={isLoading}
                        startIcon={isLoading ? null : <SaveIcon />}
                    >
                        {isLoading ? <CircularProgress size={24} /> : "Salvar"}
                    </Button>
                </CardAction>
            </Card>
        );
    } else return <Unauthorized />;
};

export default EditEducationalObject;
