/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, { useEffect, useState, useContext } from "react";
import moment from "moment";
//imports from local files
import TableData from "../../../Components/Components/Table";
import SnackBar from "../../../../Components/SnackbarComponent";
import { Url } from "../../../Filters";
import { Store } from '../../../../Store';
import LoadingSpinner from '../../../../Components/LoadingSpinner';
import { getRequest } from '../../../../Components/HelperFunctions/getAxiosConfig'
//imports from material ui
import { withStyles } from "@material-ui/core/styles";
import TableBody from "@material-ui/core/TableBody";
import TableCell from "@material-ui/core/TableCell";
import MenuItem from "@material-ui/core/MenuItem";
import TableRow from "@material-ui/core/TableRow";
import TextField from "@material-ui/core/TextField";
import IconButton from "@material-ui/core/IconButton";
import { Button, Typography, Paper, Grid } from "@material-ui/core";
import CircularProgress from "@material-ui/core/CircularProgress";
import AddRoundedIcon from "@material-ui/icons/AddRounded";
import UpdateRoundedIcon from "@material-ui/icons/UpdateRounded";
import FilterListRoundedIcon from "@material-ui/icons/FilterListRounded";
import VisibilityIcon from "@material-ui/icons/Visibility";
import LaunchRoundedIcon from "@material-ui/icons/LaunchRounded";
//routers
import { Link } from "react-router-dom";
import Unauthorized from "../../../Components/Components/Unauthorized";
import styled from "styled-components"
import MobileList from "../../../Components/Components/MobileComponents/SimpleList"
import AnnouncementRoundedIcon from "@material-ui/icons/AnnouncementRounded";

let currPage = 0;
let currStateFilter = "0"
let currComplainReasonId;
let currDescriptionFilter = "";

const StyledTableCell = withStyles((theme) => ({
    head: {
        backgroundColor: theme.palette.common.black,
        color: theme.palette.common.white,
    },
    body: {
        fontSize: 14,
    },
}))(TableCell);

const StyledTableRow = withStyles((theme) => ({
    root: {
        "&:nth-of-type(odd)": {
            backgroundColor: theme.palette.action.hover,
        },
    },
}))(TableRow);

const Complaints = () => {
    const { state } = useContext(Store);
    const WINDOW_WIDTH = window.innerWidth

    const PORTAL_MEC = "https://plataformaintegrada.mec.gov.br/";

    const ADD_ONE_LENGHT = [""];
    const TOP_LABELS = [
        "ESTADO DO RECURSO",
        "ID",
        "DESCRIÇÃO",
        "ID OBJETO",
        "TIPO",
        "DATA(MM/DD/YYYY)",
        "VISUALIZAR",
        "VISITAR",
    ]; //Labels from Table

    const [error, setError] = useState(null); //Necessary to consult the API, catch errors
    const [isLoaded, setIsLoaded] = useState(false); //Necessary to consult the API, wait until complete
    const [items, setItems] = useState([]); //Necessary to consult the API, data

    const [isLoadingMoreItems, setIsLoadingMoreItems] = useState(false); //controlls the state of loadind more data
    const [isUpdating, setIsUpdating] = useState(false); //controlls the state of updating data

    const [showFilter, setShowFilter] = useState(false);

    const [stateOption, setStateOption] = useState("Pendente");
    const [complainOption, setComplainOption] = useState("");
    const [description, setDescription] = useState("");

    const [snackInfo, setSnackInfo] = useState({
        message: "",
        icon: "",
        open: false,
        color: "",
    });

    const StateOptions = [
        { id: 0, name: "Pendente" },
        { id: 1, name: "Ativo" },
        { id: 2, name: "Bloqueado / Removido" },
    ];

    const ComplaintReasons = [
        { id: 1, name: "Viola direitos autorais" },
        { id: 2, name: "Conteúdo ofensivo/abusivo" },
        { id: 3, name: "Conta falsa" },
        { id: 4, name: "Spam" },
        { id: 5, name: "Descrição diverge do conteúdo" },
    ];

    //handle snack info
    const HandleSnack = (message, state, icon, color) => {
        setSnackInfo({
            message: message,
            icon: icon,
            open: state,
            color: color,
        });
    };

    const CheckUserPermission = () => {
        let canUserEdit = false;

        if (state.userIsLoggedIn) {
            const roles = [...state.currentUser.roles];
            for (let i = 0; i < roles.length; i++)
                if (roles[i].name === 'admin' || roles[i].name === 'editor')
                    canUserEdit = true;
        }
        else {
            canUserEdit = false;
        }

        return canUserEdit;
    }

    //handle load more items
    const LoadMoreItens = async (api) => {
        setIsLoadingMoreItems(true);
        getRequest(
            api,
            (data, header) => {
                const arrData = [...data];
                if (arrData.length === 0) {
                    HandleSnack(
                        "Não há mais dados para serem carregados",
                        true,
                        "warning",
                        "#FFC125"
                    );
                } else {
                    const arrItems = [...items];
                    arrItems.pop(); //Deleting the last position, that was used to display the button of load more items
                    const arrResult = arrItems.concat(arrData);
                    setItems(arrResult.concat(ADD_ONE_LENGHT));
                }
                setIsLoadingMoreItems(false);
            },
            (error) => {
                HandleSnack("Erro ao carregar os dados", true, "warning", "#FA8072");
                setIsLoadingMoreItems(false);
            }
        )
    };

    // handle update list data
    const UpdateHandler = async (api) => {
        setIsUpdating(true);
        getRequest(
            api,
            (data, header) => {
                HandleSnack(
                    "A lista de dados foi atualizada",
                    true,
                    "success",
                    "#228B22"
                );
                const arrData = [...data];
                setItems(arrData.concat(ADD_ONE_LENGHT));
                setIsUpdating(false);

            },
            (error) => {
                HandleSnack("Erro ao carregar os dados", true, "warning", "#FA8072");
                setIsUpdating(false);

            }
        )
    };

    const handleChangeState = (e, type) => {
        const value = e.target.value;
        setStateOption(value);
    };

    const handleChangeComplain = (e, type) => {
        const value = e.target.value;
        setComplainOption(value);
    };

    const ApplyFilterState = (id, type) => {
        currPage = 0;
        currStateFilter = id;
        let url;
        if (currComplainReasonId) {
            url = Url("complaints",
                `"state" : "${currStateFilter}", "complaint_reason_id" : "${currComplainReasonId}", "description" : "${currDescriptionFilter}"`,
                `${currPage}`,
                "DESC"
            )
        }
        else {
            url = Url("complaints",
                `"state" : "${currStateFilter}", "description" : "${currDescriptionFilter}"`,
                `${currPage}`,
                "DESC"
            )
        }
        getRequest(
            url,
            (data, header) => {
                const arrData = [...data];
                setItems(arrData.concat(ADD_ONE_LENGHT));
                HandleSnack("Filtro aplicado com sucesso", true, "success", "#228B22");
                setIsLoaded(true);
            },
            (error) => {
                HandleSnack("Erro ao carregar os dados", true, "warning", "#FA8072");
                setIsLoaded(true);
            }
        )
    };

    const ApplyFilterComplainReason = (id, type) => {
        currPage = 0;
        currComplainReasonId = id;
        let url;
        if (currComplainReasonId) {
            url = Url("complaints",
                `"state" : "${currStateFilter}", "complaint_reason_id" : "${currComplainReasonId}", "description" : "${currDescriptionFilter}"`,
                `${currPage}`,
                "DESC"
            )
        }
        else {
            url = Url("complaints",
                `"state" : "${currStateFilter}", "description" : "${currDescriptionFilter}"`,
                `${currPage}`,
                "DESC"
            )
        }
        getRequest(
            url,
            (data, header) => {
                const arrData = [...data];
                setItems(arrData.concat(ADD_ONE_LENGHT));
                HandleSnack("Filtro aplicado com sucesso", true, "success", "#228B22");
                setIsLoaded(true);
            },
            (error) => {
                HandleSnack("Erro ao carregar os dados", true, "warning", "#FA8072");
                setIsLoaded(true);
            }
        )
    };

    const DescriptionHandler = (e) => {
        currPage = 0;
        currDescriptionFilter = e.target.value;
        setDescription(currDescriptionFilter)
        let url;
        if (currComplainReasonId) {
            url = Url("complaints",
                `"state" : "${currStateFilter}", "complaint_reason_id" : "${currComplainReasonId}", "description" : "${currDescriptionFilter}"`,
                `${currPage}`,
                "DESC"
            )
        }
        else {
            url = Url("complaints",
                `"state" : "${currStateFilter}", "description" : "${currDescriptionFilter}"`,
                `${currPage}`,
                "DESC"
            )
        }
        getRequest(
            url,
            (data, header) => {
                const arrData = [...data];
                setItems(arrData.concat(ADD_ONE_LENGHT));
                HandleSnack("Filtro aplicado com sucesso", true, "success", "#228B22");
                setIsLoaded(true);
            },
            (error) => {
                HandleSnack("Erro ao carregar os dados", true, "warning", "#FA8072");
                setIsLoaded(true);
            }
        )
    }

    const convertToLink = (type, id) => {
        switch (type) {
            case "LearningObject":
                return `recurso?id=${id}/`;
            case "User":
                return `usuario-publico/${id}/`;
            default:
                return "";
        }
    };

    const ComplaintStatus = (status, type) => {
        switch (status) {
            case "accepted":
                return (
                    <Paper
                        style={{
                            textAlign: "center",
                            padding: "0.5em",
                            backgroundColor: "#FA8072",
                            fontWeight: "500",
                            color: "#FFFAFA",
                        }}
                    >
                        {
                            type === "User" ? "BLOQUEADO" : "REMOVIDO"
                        }
                    </Paper>
                );
            case "complained":
                return (
                    <Paper
                        style={{
                            textAlign: "center",
                            padding: "0.5em",
                            backgroundColor: "#FF8C00",
                            fontWeight: "500",
                            color: "#FFFAFA",
                        }}
                    >
                        PENDENTE
                    </Paper>
                );
            case "rejected":
                return (
                    <Paper
                        style={{
                            textAlign: "center",
                            padding: "0.5em",
                            backgroundColor: "#228B22",
                            fontWeight: "500",
                            color: "#FFFAFA",
                        }}
                    >
                        REJEITADO
                    </Paper>
                );
            default:
                return "NOTHING";
        }
    };

    const DisplayDate = (date) => {
        const convertedData = moment.utc(date);
        return moment(convertedData)
            .format("LLL")
            .toString();
    };

    //getting data from server
    useEffect(() => {
        getRequest(
            Url("complaints", `"state" : "${currStateFilter}"`, `${currPage}`, "DESC"),
            (data, header) => {
                const arrData = [...data];
                setItems(arrData.concat(ADD_ONE_LENGHT));
                setIsLoaded(true);
                setError(false);
            },
            (error) => {
                HandleSnack("Erro ao carregar os dados", true, "warning", "#FA8072");
                setIsLoaded(true);
                setError(true);
            }
        )
    }, []);

    if (error) {
        return <div>Error: {error.message}</div>;
    } else if (!isLoaded) {
        return <LoadingSpinner text="Carregando..." />
    } else if (CheckUserPermission()) {
        if (WINDOW_WIDTH <= 994) {
            return (
                <>
                    <SnackBar
                        severity={snackInfo.icon}
                        text={snackInfo.message}
                        snackbarOpen={snackInfo.open}
                        color={snackInfo.color}
                        handleClose={() =>
                            setSnackInfo({
                                message: "",
                                icon: "",
                                open: false,
                                color: "",
                            })
                        }
                    />

                    <Paper style={{ padding: "1em" }}>
                        <Grid container spacing={3} direction="row" alignItems="center">
                            <Grid item xs={12}>
                                <Typography variant="h4">Denúncias</Typography>
                            </Grid>

                            <Grid
                                item
                                xs={12}        
                            >
                                <Grid container justify="flex-start" spacing={3}>
                                    <Grid item>
                                        <Button
                                            variant="contained"
                                            color="secondary"
                                            disabled={isUpdating}
                                            onClick={() => {
                                                currPage = 0;
                                                if (currComplainReasonId) {
                                                    UpdateHandler(
                                                        Url("complaints",
                                                            `"state" : "${currStateFilter}", "complaint_reason_id" : "${currComplainReasonId}", "description" : "${currDescriptionFilter}"`,
                                                            `${currPage}`,
                                                            "DESC"
                                                        )
                                                    );
                                                }
                                                else {
                                                    UpdateHandler(
                                                        Url("complaints",
                                                            `"state" : "${currStateFilter}", "description" : "${currDescriptionFilter}"`,
                                                            `${currPage}`,
                                                            "DESC"
                                                        )
                                                    );
                                                }
                                            }}
                                            startIcon={<UpdateRoundedIcon />}
                                        >
                                            {isUpdating ? <CircularProgress size={24} /> : "Atualizar"}
                                        </Button>
                                    </Grid>
                                    <Grid item>
                                        <Button
                                            variant="contained"
                                            color="secondary"
                                            onClick={() => {
                                                setShowFilter(!showFilter);
                                            }}
                                            startIcon={<FilterListRoundedIcon />}
                                        >
                                            Filtrar
                                        </Button>
                                    </Grid>
                                </Grid>
                            </Grid>
                        </Grid>

                        {showFilter ? (
                            <Grid
                                container
                                direction="row"
                                justify="space-between"
                                alignItems="center"
                                alignContent="flex-end"
                                spacing={3}
                                xs={12}
                            >
                                <Grid item>
                                    <TextField
                                        select
                                        label="Motivo"
                                        value={complainOption}
                                        onChange={handleChangeComplain}
                                        helperText="Por favor, selecione uma das opções"
                                    >
                                        {ComplaintReasons.map((option, index) => (
                                            <MenuItem
                                                key={option.id}
                                                value={option.name}
                                                name={option.id}
                                                onClick={() =>
                                                    ApplyFilterComplainReason(option.id, "complaint_reason_id")
                                                }
                                            >
                                                {option.name}
                                            </MenuItem>
                                        ))}
                                    </TextField>
                                </Grid>
                                <Grid item>
                                    <TextField
                                        select
                                        label="Estado"
                                        value={stateOption}
                                        onChange={handleChangeState}
                                        helperText="Por favor, selecione uma das opções"
                                    >
                                        {StateOptions.map((option, index) => (
                                            <MenuItem
                                                key={option.id}
                                                value={option.name}
                                                name={option.id}
                                                onClick={() => ApplyFilterState(option.id, "state")}
                                            >
                                                {option.name}
                                            </MenuItem>
                                        ))}
                                    </TextField>
                                </Grid>
                                <Grid item>
                                    <TextField label="Descrição" onChange={DescriptionHandler} value={description} />
                                </Grid>
                            </Grid>
                        ) : null}
                    </Paper>

                    <div style={{ height: "2em" }}></div>

                    {items.map((row, index) =>
                        index === items.length - 1 ? (
                            <StyledDivButton>
                                <Button
                                    key={index}
                                    color="primary"
                                    variant="text"
                                    // disabled={isLoadingMoreItems}
                                    startIcon={<AddRoundedIcon />}
                                    disabled={isLoadingMoreItems}
                                    onClick={() => {
                                        currPage++;
                                        if (currComplainReasonId) {
                                            LoadMoreItens(
                                                Url("complaints",
                                                    `"state" : "${currStateFilter}", "complaint_reason_id" : "${currComplainReasonId}", "description" : "${currDescriptionFilter}"`,
                                                    `${currPage}`,
                                                    "DESC"
                                                )
                                            );
                                        }
                                        else {
                                            LoadMoreItens(
                                                Url("complaints",
                                                    `"state" : "${currStateFilter}", "description" : "${currDescriptionFilter}"`,
                                                    `${currPage}`,
                                                    "DESC"
                                                )
                                            );
                                        }
                                    }}
                                >
                                    {isLoadingMoreItems ? (
                                        <CircularProgress size={24} />
                                    ) : (
                                            "Carregar mais itens"
                                        )}
                                </Button>
                            </StyledDivButton>
                        ) : (
                                <>
                                    <MobileList
                                        key={index}
                                        title={row.complainable_type}
                                        subtitle={row.id}
                                        backColor={"#673ab7"}
                                        avatar={<AnnouncementRoundedIcon />}
                                        href={`/admin/complaint/${row.id}`}
                                        reset={() => {
                                            currPage = 0
                                            currStateFilter = "0"
                                            currDescriptionFilter = ""
                                            currComplainReasonId = null;
                                        }}
                                        data={
                                            [
                                                {
                                                    title: "ID do objeto",
                                                    subtitle: row.complainable_id

                                                },
                                                {
                                                    title: "Criado em",
                                                    subtitle: DisplayDate(row.created_at)
                                                },
                                                {
                                                    title: "Descrição",
                                                    subtitle: row.description
                                                },
                                                {
                                                    title: "Estado",
                                                    subtitle: ComplaintStatus(row.state, row.complainable_type)
                                                }
                                            ]
                                        }
                                    />
                                    <div style={{ height: "0.5em" }} />
                                </>
                            )
                    )}
                </>
            );
        }
        else {
            return (
                <>
                    <SnackBar
                        severity={snackInfo.icon}
                        text={snackInfo.message}
                        snackbarOpen={snackInfo.open}
                        color={snackInfo.color}
                        handleClose={() =>
                            setSnackInfo({
                                message: "",
                                icon: "",
                                open: false,
                                color: "",
                            })
                        }
                    />

                    <Paper style={{ padding: "1em" }}>
                        <Grid container spacing={3} direction="row" alignItems="center">
                            <Grid item xs={6}>
                                <Typography variant="h4">Denúncias</Typography>
                            </Grid>

                            <Grid
                                item
                                xs={6}
                            >
                                <Grid container justify="flex-end" spacing={3}>
                                    <Grid item>
                                        <Button
                                            variant="contained"
                                            color="secondary"
                                            disabled={isUpdating}
                                            onClick={() => {
                                                currPage = 0;
                                                if (currComplainReasonId) {
                                                    UpdateHandler(
                                                        Url("complaints",
                                                            `"state" : "${currStateFilter}", "complaint_reason_id" : "${currComplainReasonId}", "description" : "${currDescriptionFilter}"`,
                                                            `${currPage}`,
                                                            "DESC"
                                                        )
                                                    );
                                                }
                                                else {
                                                    UpdateHandler(
                                                        Url("complaints",
                                                            `"state" : "${currStateFilter}", "description" : "${currDescriptionFilter}"`,
                                                            `${currPage}`,
                                                            "DESC"
                                                        )
                                                    );
                                                }
                                            }}
                                            startIcon={<UpdateRoundedIcon />}
                                        >
                                            {isUpdating ? <CircularProgress size={24} /> : "Atualizar"}
                                        </Button>
                                    </Grid>
                                    <Grid item>
                                        <Button
                                            variant="contained"
                                            color="secondary"
                                            onClick={() => {
                                                setShowFilter(!showFilter);
                                            }}
                                            startIcon={<FilterListRoundedIcon />}
                                        >
                                            Filtrar
                                        </Button>
                                    </Grid>
                                </Grid>
                            </Grid>
                        </Grid>

                        {showFilter ? (
                            <Grid
                                container
                                direction="row"
                                justify="space-between"
                                alignItems="center"
                                alignContent="flex-end"
                                spacing={3}
                                xs={12}
                            >
                                <Grid item>
                                    <TextField
                                        select
                                        label="Motivo"
                                        value={complainOption}
                                        onChange={handleChangeComplain}
                                        helperText="Por favor, selecione uma das opções"
                                    >
                                        {ComplaintReasons.map((option, index) => (
                                            <MenuItem
                                                key={option.id}
                                                value={option.name}
                                                name={option.id}
                                                onClick={() =>
                                                    ApplyFilterComplainReason(option.id, "complaint_reason_id")
                                                }
                                            >
                                                {option.name}
                                            </MenuItem>
                                        ))}
                                    </TextField>
                                </Grid>
                                <Grid item>
                                    <TextField
                                        select
                                        label="Estado"
                                        value={stateOption}
                                        onChange={handleChangeState}
                                        helperText="Por favor, selecione uma das opções"
                                    >
                                        {StateOptions.map((option, index) => (
                                            <MenuItem
                                                key={option.id}
                                                value={option.name}
                                                name={option.id}
                                                onClick={() => ApplyFilterState(option.id, "state")}
                                            >
                                                {option.name}
                                            </MenuItem>
                                        ))}
                                    </TextField>
                                </Grid>
                                <Grid item>
                                    <TextField label="Descrição" onChange={DescriptionHandler} value={description} />
                                </Grid>
                            </Grid>
                        ) : null}
                    </Paper>

                    <div style={{ height: "2em" }}></div>

                    <Grid xs={12} container>
                        <TableData top={TOP_LABELS}>
                            <TableBody>
                                {items.map((row, index) =>
                                    index === items.length - 1 ? (
                                        <StyledTableRow key={index}>
                                            {/* Button to load more data */}
                                            <StyledTableCell>
                                                <Button
                                                    color="primary"
                                                    variant="text"
                                                    // disabled={isLoadingMoreItems}
                                                    startIcon={<AddRoundedIcon />}
                                                    disabled={isLoadingMoreItems}
                                                    onClick={() => {
                                                        currPage++;
                                                        if (currComplainReasonId) {
                                                            LoadMoreItens(
                                                                Url("complaints",
                                                                    `"state" : "${currStateFilter}", "complaint_reason_id" : "${currComplainReasonId}", "description" : "${currDescriptionFilter}"`,
                                                                    `${currPage}`,
                                                                    "DESC"
                                                                )
                                                            );
                                                        }
                                                        else {
                                                            LoadMoreItens(
                                                                Url("complaints",
                                                                    `"state" : "${currStateFilter}", "description" : "${currDescriptionFilter}"`,
                                                                    `${currPage}`,
                                                                    "DESC"
                                                                )
                                                            );
                                                        }
                                                    }}
                                                >
                                                    {isLoadingMoreItems ? (
                                                        <CircularProgress size={24} />
                                                    ) : (
                                                            "Carregar mais itens"
                                                        )}
                                                </Button>
                                            </StyledTableCell>
                                        </StyledTableRow>
                                    ) : (
                                            <StyledTableRow
                                                key={index}
                                                style={{ flex: 1, width: "100%" }}
                                            >
                                                <StyledTableCell component="th" scope="row">
                                                    {ComplaintStatus(row.state, row.complainable_type)}
                                                </StyledTableCell>
                                                <StyledTableCell align="right">{row.id}</StyledTableCell>
                                                <StyledTableCell align="right">
                                                    {row.description}
                                                </StyledTableCell>
                                                <StyledTableCell align="right">
                                                    {row.complainable_id}
                                                </StyledTableCell>
                                                <StyledTableCell align="right">
                                                    {row.complainable_type}
                                                </StyledTableCell>
                                                <StyledTableCell align="right">
                                                    {DisplayDate(row.created_at)}
                                                </StyledTableCell>
                                                <StyledTableCell align="right">
                                                    <Link to={`/admin/complaint/${row.id}`}>
                                                        <IconButton
                                                            onClick={() => {
                                                                currPage = 0
                                                                currStateFilter = "0"
                                                                currDescriptionFilter = ""
                                                                currComplainReasonId = null;
                                                            }}
                                                        >
                                                            <VisibilityIcon style={{ fill: "#00bcd4" }} />
                                                        </IconButton>
                                                    </Link>
                                                </StyledTableCell>
                                                <StyledTableCell align="right">
                                                    <Button
                                                        variant="text"
                                                        secondary={true}
                                                        startIcon={
                                                            <LaunchRoundedIcon style={{ fill: "#FA8072" }} />
                                                        }
                                                    >
                                                        <a
                                                            style={{
                                                                textDecoration: "none",
                                                                color: "#FA8072",
                                                            }}
                                                            target="_blank"
                                                            rel="noreferrer"
                                                            href={
                                                                PORTAL_MEC +
                                                                convertToLink(
                                                                    row.complainable_type,
                                                                    row.complainable_id
                                                                )
                                                            }
                                                        >
                                                            MEC RED
                                                        </a>
                                                    </Button>
                                                </StyledTableCell>
                                            </StyledTableRow>
                                        )
                                )}
                            </TableBody>
                        </TableData>
                    </Grid>
                </>
            );
        }
    } else return <Unauthorized />
};
export default Complaints;

const StyledDivButton = styled(Paper)`
    width : 100%;
    display : flex; 
    justify-content : center; 
    align-items : center; 
`

